InitUI class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
init({required String baseUrl, required String title, bool debugShowCheckedModeBanner = true, ThemeData theme = const ThemeData(colorScheme: ColorSchemes.lightNeutral, surfaceOpacity: 0.8, surfaceBlur: 4.0), String defaultPage = "/ui/main"})
→ Widget
-